==> Pyrogram-1.0.2-py3-none-any.whl: pyrogram/raw/base/secure_value_type.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

SecureValueType = Union[raw.types.SecureValueTypeAddress, raw.types.SecureValueTypeBankStatement, raw.types.SecureValueTypeDriverLicense, raw.types.SecureValueTypeEmail, raw.types.SecureValueTypeIdentityCard, raw.types.SecureValueTypeInternalPassport, raw.types.SecureValueTypePassport, raw.types.SecureValueTypePassportRegistration, raw.types.SecureValueTypePersonalDetails, raw.types.SecureValueTypePhone, raw.types.SecureValueTypeRentalAgreement, raw.types.SecureValueTypeTemporaryRegistration, raw.types.SecureValueTypeUtilityBill]


# noinspection PyRedeclaration
class SecureValueType(TLObject):  # type: ignore
    """This base type has 13 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`SecureValueTypeAddress <pyrogram.raw.types.SecureValueTypeAddress>`
            - :obj:`SecureValueTypeBankStatement <pyrogram.raw.types.SecureValueTypeBankStatement>`
            - :obj:`SecureValueTypeDriverLicense <pyrogram.raw.types.SecureValueTypeDriverLicense>`
            - :obj:`SecureValueTypeEmail <pyrogram.raw.types.SecureValueTypeEmail>`
            - :obj:`SecureValueTypeIdentityCard <pyrogram.raw.types.SecureValueTypeIdentityCard>`
            - :obj:`SecureValueTypeInternalPassport <pyrogram.raw.types.SecureValueTypeInternalPassport>`
            - :obj:`SecureValueTypePassport <pyrogram.raw.types.SecureValueTypePassport>`
            - :obj:`SecureValueTypePassportRegistration <pyrogram.raw.types.SecureValueTypePassportRegistration>`
            - :obj:`SecureValueTypePersonalDetails <pyrogram.raw.types.SecureValueTypePersonalDetails>`
            - :obj:`SecureValueTypePhone <pyrogram.raw.types.SecureValueTypePhone>`
            - :obj:`SecureValueTypeRentalAgreement <pyrogram.raw.types.SecureValueTypeRentalAgreement>`
            - :obj:`SecureValueTypeTemporaryRegistration <pyrogram.raw.types.SecureValueTypeTemporaryRegistration>`
            - :obj:`SecureValueTypeUtilityBill <pyrogram.raw.types.SecureValueTypeUtilityBill>`
    """

    QUALNAME = "pyrogram.raw.base.SecureValueType"

==> Pyrogram-1.0.4-py3-none-any.whl: pyrogram/raw/base/secure_value_type.py <==
#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2020 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

SecureValueType = Union[raw.types.SecureValueTypeAddress, raw.types.SecureValueTypeBankStatement, raw.types.SecureValueTypeDriverLicense, raw.types.SecureValueTypeEmail, raw.types.SecureValueTypeIdentityCard, raw.types.SecureValueTypeInternalPassport, raw.types.SecureValueTypePassport, raw.types.SecureValueTypePassportRegistration, raw.types.SecureValueTypePersonalDetails, raw.types.SecureValueTypePhone, raw.types.SecureValueTypeRentalAgreement, raw.types.SecureValueTypeTemporaryRegistration, raw.types.SecureValueTypeUtilityBill]


# noinspection PyRedeclaration
class SecureValueType:  # type: ignore
    """This base type has 13 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`SecureValueTypeAddress <pyrogram.raw.types.SecureValueTypeAddress>`
            - :obj:`SecureValueTypeBankStatement <pyrogram.raw.types.SecureValueTypeBankStatement>`
            - :obj:`SecureValueTypeDriverLicense <pyrogram.raw.types.SecureValueTypeDriverLicense>`
            - :obj:`SecureValueTypeEmail <pyrogram.raw.types.SecureValueTypeEmail>`
            - :obj:`SecureValueTypeIdentityCard <pyrogram.raw.types.SecureValueTypeIdentityCard>`
            - :obj:`SecureValueTypeInternalPassport <pyrogram.raw.types.SecureValueTypeInternalPassport>`
            - :obj:`SecureValueTypePassport <pyrogram.raw.types.SecureValueTypePassport>`
            - :obj:`SecureValueTypePassportRegistration <pyrogram.raw.types.SecureValueTypePassportRegistration>`
            - :obj:`SecureValueTypePersonalDetails <pyrogram.raw.types.SecureValueTypePersonalDetails>`
            - :obj:`SecureValueTypePhone <pyrogram.raw.types.SecureValueTypePhone>`
            - :obj:`SecureValueTypeRentalAgreement <pyrogram.raw.types.SecureValueTypeRentalAgreement>`
            - :obj:`SecureValueTypeTemporaryRegistration <pyrogram.raw.types.SecureValueTypeTemporaryRegistration>`
            - :obj:`SecureValueTypeUtilityBill <pyrogram.raw.types.SecureValueTypeUtilityBill>`
    """

    QUALNAME = "pyrogram.raw.base.SecureValueType"
